/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.banking.ri.blzdirectory;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class BundesbankBankleitzahlenVerzeichnisBundle
{

  /** Singleton instance. */
  private static final BundesbankBankleitzahlenVerzeichnisBundle instance =
    new BundesbankBankleitzahlenVerzeichnisBundle();

  /** Creates a new {@code BundesbankBankleitzahlenVerzeichnisBundle} instance. */
  BundesbankBankleitzahlenVerzeichnisBundle()
  {
    this.getMessage ( "outdatedInfo", Locale.getDefault() );
    this.getMessage ( "fileNameInfo", Locale.getDefault() );
    this.getMessage ( "duplicateRecord", Locale.getDefault() );
  }

  /**
   * Gets the {@code BundesbankBankleitzahlenVerzeichnisBundle} singleton.
   *
   * @return the {@code BundesbankBankleitzahlenVerzeichnisBundle} singleton.
   */
  static BundesbankBankleitzahlenVerzeichnisBundle getInstance()
  {
    return instance;
  }

  /**
   * Gets the text of the message with key {@code "outdatedInfo"}.
   *
   * @return <pre>
   * Bankleitzahl {0} is outdated.</pre>
   */
  String getOutdatedInfoText ( final Locale locale )
  {
    return this.getMessage ( "outdatedInfo", locale );
  }

  /**
   * Gets the message with key {@code "outdatedInfo"}.
   *
   * @return <pre>
   * Bankleitzahl {0} is outdated.</pre>
   */
  MessageFormat getOutdatedInfoMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "outdatedInfo", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "fileNameInfo"}.
   *
   * @return <pre>
   * Loading Bankleitzahlendatei "{0}".</pre>
   */
  String getFileNameInfoText ( final Locale locale )
  {
    return this.getMessage ( "fileNameInfo", locale );
  }

  /**
   * Gets the message with key {@code "fileNameInfo"}.
   *
   * @return <pre>
   * Loading Bankleitzahlendatei "{0}".</pre>
   */
  MessageFormat getFileNameInfoMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "fileNameInfo", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "duplicateRecord"}.
   *
   * @return <pre>
   * Multiple bankfile records with serial number {0,number} detected during searching the directory for bankcode {1}.</pre>
   */
  String getDuplicateRecordText ( final Locale locale )
  {
    return this.getMessage ( "duplicateRecord", locale );
  }

  /**
   * Gets the message with key {@code "duplicateRecord"}.
   *
   * @return <pre>
   * Multiple bankfile records with serial number {0,number} detected during searching the directory for bankcode {1}.</pre>
   */
  MessageFormat getDuplicateRecordMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "duplicateRecord", locale ), locale );
  }

  /**
   * Gets a message for a given key and locale.
   *
   * @param key the key of the message to return.
   * @param locale the locale of the message.
   *
   * @return message for {@code key} using {@code locale}.
   */
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/banking/ri/blzdirectory/BundesbankBankleitzahlenVerzeichnis",
                                     locale ).getString( key );

  }
}
